@@ -484,7 +484,7 @@ imputev <- function (x, method = "median") {
   return(x)
 }
 
-rrc <- function(x=NULL, H=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE){
+rrm <- function(x=NULL, H=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE, sep=""){
   if(is.null(x) ){stop("Please provide the x argument.", call. = FALSE)}
   if(is.null(H) ){stop("Please provide the x argument.", call. = FALSE)}
   # these are called PC models by Meyer 2009, GSE. This is a reduced rank implementation
@@ -492,6 +492,7 @@ rrc <- function(x=NULL, H=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE){
   
   Y <- apply(H,2, imputev)
   Sigma <- cov(scale(Y, scale = TRUE, center = TRUE)) # surrogate of unstructured matrix to start with
+  Sigma[which(is.na(Sigma), arr.ind = TRUE)]=0
   Sigma <- as.matrix(nearPD(Sigma)$mat)
   # GE <- as.data.frame(t(scale( t(scale(Y, center=T,scale=F)), center=T, scale=F)))  # sum(GE^2)
   if(cholD){
@@ -511,7 +512,7 @@ rrc <- function(x=NULL, H=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE){
   rownames(Gamma) <- rownamesGamma
   ##
   rownames(Gamma) <- gsub("v.names_","",rownames(Gamma))#rownames(GE)#levels(dataset$Genotype);  # rownames(Se) <- colnames(GE)#levels(dataset$Environment)
-  colnames(Gamma) <- paste("PC", 1:ncol(Gamma), sep =""); # 
+  colnames(Gamma) <- paste("PC", 1:ncol(Gamma), sep =sep); # 
   ######### GEreduced = Sg %*% t(Se) 
   # if we want to merge with PCs for environments
   dtx <- data.frame(timevar=x)
@@ -523,13 +524,13 @@ rrc <- function(x=NULL, H=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE){
   rownames(Z) <- NULL
   
   if(returnGamma){
-    return(list(Gamma=Gamma, H=H, Sigma=Sigma))
+    return(list(Gamma=Gamma, H=H, Sigma=Sigma, Zstar=Zstar))
   }else{
     return(Zstar)
   }
 }
 
-dsc <- function(x, thetaC=NULL, theta=NULL){
+smm <- function(x){
   if(is.matrix(x)){
     dummy <- x
     mm <- diag(1,ncol(x))
@@ -552,21 +553,22 @@ dsc <- function(x, thetaC=NULL, theta=NULL){
       mm <- diag(1,ncol(dummy))
     }
   }
-  colnames(mm) <- rownames(mm) <- colnames(dummy)
-  bnmm <- mm*0.15
-  if(nrow(bnmm) > 1){
-    bnmm[upper.tri(bnmm)]=bnmm[upper.tri(bnmm)]/2
-  }
-  if(!is.null(thetaC)){
-    mm <- thetaC
-    colnames(mm) <- rownames(mm) <- colnames(dummy)
-  }
-  if(!is.null(theta)){
-    bnmm <- theta
-    colnames(bnmm) <- rownames(bnmm) <- colnames(dummy)
-  }
-  mm[lower.tri(mm)]=0
-  return(list(Z=dummy,thetaC=mm, theta=bnmm))
+  # colnames(mm) <- rownames(mm) <- colnames(dummy)
+  # bnmm <- mm*0.15
+  # if(nrow(bnmm) > 1){
+  #   bnmm[upper.tri(bnmm)]=bnmm[upper.tri(bnmm)]/2
+  # }
+  # if(!is.null(thetaC)){
+  #   mm <- thetaC
+  #   colnames(mm) <- rownames(mm) <- colnames(dummy)
+  # }
+  # if(!is.null(theta)){
+  #   bnmm <- theta
+  #   colnames(bnmm) <- rownames(bnmm) <- colnames(dummy)
+  # }
+  # mm[lower.tri(mm)]=0
+  # return(list(Z=dummy,thetaC=mm, theta=bnmm))
+  return(dummy)
 }
 
 atcg1234 <- function(data, ploidy=2, format="ATCG", maf=0, multi=TRUE, silent=FALSE, 
