@@ -42,7 +42,7 @@ DT <- DT_example
 A <- A_example
 head(DT)
 ## Compound simmetry (CS) + Diagonal (DIAG) model
-Z <- with(DT, dsc(Env))$Z
+Z <- with(DT, smm(Env))
 csdiagFormula <- paste0( "Yield ~ Env + (", paste(colnames(Z), collapse = "+"), "|| Name)")
 for(i in 1:ncol(Z)){DT[,colnames(Z)[i]] <- Z[,i]}
 ansCSDG <- lmebreed(as.formula(csdiagFormula),
